<?php 

add_action('after_setup_theme', 'gulf_load_acf');
function gulf_load_acf() {
	if (!class_exists('acf')) {
		add_filter('acf/settings/path', 'gulf_acf_settings_path');
		add_filter('acf/settings/dir', 'gulf_acf_settings_dir');
		if (!defined('GULF_MASTER') || GULF_MASTER==false) { 
			add_filter('acf/settings/show_admin', '__return_false'); // Hide ACF field group menu item
		}
		add_filter('acf/settings/save_json', 'my_acf_json_save_point');
		add_filter('acf/settings/load_json', 'my_acf_json_load_point');
		add_filter('acf/settings/google_api_key', function () {
			return GOOGLE_API_KEY;
		});		
		add_filter('acf/load_field/name=country', 'acf_load_country_field_choices');
		// Include ACF
		include_once( get_template_directory() . '/vendor/acf/acf.php' );
		
		// Do ACF stuff
		gulf_acf_calls();
	}
}

// Customize ACF path
function gulf_acf_settings_path( $path ) {
    return get_template_directory() . '/vendor/acf/';
}
 

// Customize ACF dir
function gulf_acf_settings_dir( $dir ) {
	return get_template_directory_uri() . '/vendor/acf/';
}


// Save/Load json settings
function my_acf_json_save_point( $path ) {
    return get_template_directory() . '/inc/acf-settings';
}
function my_acf_json_load_point( $paths ) {
    unset($paths[0]);
    $paths[] = get_template_directory() . '/inc/acf-settings';
    return $paths;
}


// Country fields
function acf_load_country_field_choices($field ) {
	$field['choices'] = gulf_country_list();
	return $field;
}


function gulf_acf_calls() {
	if( function_exists('acf_add_options_page')) {
		acf_add_options_page(array(
			'page_title' 	=> 'Gulf Theme General Settings',
			'menu_title'	=> 'Gulf Theme Settings',
			'menu_slug' 	=> 'gulf-theme-general-settings',
			'capability'	=> 'edit_posts',
			'redirect'		=> false
		));

		add_filter('acf/load_field/name=services', 'acf_load_services_field_choices');

	}
}

		
function acf_load_services_field_choices( $field ) {
    
    // reset choices
    $field['choices'] = array();
    
    
    // get the textarea value from options page without any formatting
    $choices = get_field('distributor_services', 'option');
    
    // explode the value so that each line is a new array piece
    $choices = explode("\n", $choices);

    
    // remove any unwanted white space
    $choices = array_map('trim', $choices);

    
    // loop through array and add to field 'choices'
    if( is_array($choices) ) {
        
        foreach( $choices as $choice ) {
            
            $field['choices'][ $choice ] = $choice;
            
        }
        
    }
    

    // return the field
    return $field;
    
}
